@@ -19,7 +19,7 @@ seg.num.fit.boot <- function(y, XREG, Z, PSI, w, opz, n.boot=10, size.boot=NULL,
 #      ss
 #      }
 #--------
-extract.psi<-function(lista){
+      extract.psi<-function(lista){
 #serve per estrarre il miglior psi..
     	dev.values<-lista[[1]][-1] #remove the 1st one referring to model without psi
     	psi.values<-lista[[2]][-1] #remove the 1st one (NA)
@@ -34,12 +34,28 @@ extract.psi<-function(lista){
 	}
 #-------------
       #seg.num.fit<-if(sparse) seg.num.spar.fit else seg.num.fit 
-
+      if(is.null(opz$seed)){
+        mY <- mean(y)
+        vv <- strsplit(paste(strsplit(paste(mY),"\\.")[[1]], collapse=""),"")[[1]]
+        vv<-vv[vv!="0"]
+        vv=na.omit(vv[1:5])
+        seed <-eval(parse(text=paste(vv, collapse="")))
+        set.seed(seed)
+      } else {
+        if(is.na(opz$seed)) {
+          seed <-eval(parse(text=paste(sample(0:9, size=6), collapse="")))
+          set.seed(seed)
+        } else {
+          seed <-opz$seed
+          set.seed(opz$seed)
+        }
+      }  
+      
       visualBoot<-opz$visualBoot
       opz.boot<-opz
       opz.boot$pow=c(1,1) #c(1.1,1.2)
       opz1<-opz
-      opz1$it.max <-1
+      opz1$it.max <- 0
       n<-length(y)
       o0<-try(suppressWarnings(seg.num.fit(y, XREG, Z, PSI, w, opz, return.all.sol=FALSE)), silent=TRUE)
       rangeZ <- apply(Z, 2, range) #serve sempre
@@ -176,9 +192,11 @@ extract.psi<-function(lista){
       if(is.null(o0$obj)){
           PSI1 <- matrix(rep(est.psi0, rep(nrow(Z), length(est.psi0))), ncol = length(est.psi0))
           o0<-try(suppressWarnings(seg.num.fit(y, XREG, Z, PSI1, w, opz1)), silent=TRUE)
+          warning("The final fit can be unreliable (possibly mispecified segmented relationship)", call.=FALSE, immediate.=TRUE)
       }
       if(!is.list(o0)) return(0)
       o0$boot.restart<-ris
-      rm(.Random.seed, envir=globalenv())
+      o0$seed <- seed
+      #rm(.Random.seed, envir=globalenv())
       return(o0)
       }
\ No newline at end of file
